export CLOUDSDK_ROOT_DIR=/opt/google-cloud-cli
export GOOGLE_CLOUD_SDK_HOME=$CLOUDSDK_ROOT_DIR

#  CLOUDSDK_ROOT_DIR             # installation root dir
#  CLOUDSDK_PYTHON               # python interpreter path
#  CLOUDSDK_GSUTIL_PYTHON        # python interpreter path for gsutil
#  CLOUDSDK_PYTHON_ARGS          # python interpreter arguments
#  CLOUDSDK_PYTHON_SITEPACKAGES  # use python site packages
#  CLOUDSDK_BQ_PYTHON            # python interpreter for bq
#  CLOUDSDK_ENCODING             # python io encoding for gcloud
